Module: DbdocEngine::ChangelogsHelper
- Defined in:
- app/helpers/dbdoc_engine/changelogs_helper.rb
Instance Method Summary collapse
-
#action_type_options ⇒ Object
Returns an array of options for the action type select dropdown Used for filtering changelogs by action type.
-
#entity_type_options ⇒ Object
Returns an array of options for the entity type select dropdown Used for filtering changelogs by entity type.
Instance Method Details
#action_type_options ⇒ Object
Returns an array of options for the action type select dropdown Used for filtering changelogs by action type
18 19 20 21 22 23 24 25 |
# File 'app/helpers/dbdoc_engine/changelogs_helper.rb', line 18 def [ ['All Actions', ''], # Option to show all action types ['Create', 'create'], ['Update', 'update'], ['Delete', 'delete'] ] end |
#entity_type_options ⇒ Object
Returns an array of options for the entity type select dropdown Used for filtering changelogs by entity type
7 8 9 10 11 12 13 14 |
# File 'app/helpers/dbdoc_engine/changelogs_helper.rb', line 7 def [ ['All Types', ''], # Option to show all entity types ['Table Group', 'table_group'], ['Table', 'table'], ['Column', 'column'] ] end |